==> pipewire-docs-1%3A0.3.58-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/search/variables_d.js <==
var searchData=
[
  ['map_0',['map',['../structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515',1,'pw_memblock']]],
  ['mapoffset_1',['mapoffset',['../structspa__data.html#a75b63dcf6ea09c5908b8682f1696eeae',1,'spa_data']]],
  ['mask_2',['mask',['../structspa__source.html#ad43d6b5fd83f3e86be4f6103009370cd',1,'spa_source']]],
  ['matrix_3',['matrix',['../structspa__video__colorimetry.html#aa2b220b0a2586562f3547505f851fd21',1,'spa_video_colorimetry']]],
  ['max_4',['max',['../structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1',1,'pw_stream_control::max()'],['../structspa__io__latency.html#a5f23744c90a1dc0e9f0c1e067b8d390a',1,'spa_io_latency::max()']]],
  ['max_5falign_5',['max_align',['../structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7',1,'spa_buffer_alloc_info']]],
  ['max_5fframerate_6',['max_framerate',['../structspa__video__info__h264.html#af680ca708a6fac71a3236cb73e1e1fc1',1,'spa_video_info_h264::max_framerate()'],['../structspa__video__info__mjpg.html#a79a7bc729e3b98faa7285d6475b9867b',1,'spa_video_info_mjpg::max_framerate()'],['../structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb',1,'spa_video_info_raw::max_framerate()']]],
  ['max_5finput_5fports_7',['max_input_ports',['../structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e',1,'pw_node_info::max_input_ports()'],['../structspa__node__info.html#a9f05f762157f2ae9db446937f19da173',1,'spa_node_info::max_input_ports()']]],
  ['max_5fns_8',['max_ns',['../structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e',1,'spa_latency_info']]],
  ['max_5foutput_5fports_9',['max_output_ports',['../structpw__node__info.html#ac312e1844784e77e412f6bb341814372',1,'pw_node_info::max_output_ports()'],['../structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5',1,'spa_node_info::max_output_ports()']]],
  ['max_5fquantum_10',['max_quantum',['../structspa__latency__info.html#aab5617769d3799f99a80747917268db8',1,'spa_latency_info']]],
  ['max_5frate_11',['max_rate',['../structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec',1,'spa_latency_info']]],
  ['max_5fsize_12',['max_size',['../structspa__io__range.html#adac0f561e72d269206216a3327720ff7',1,'spa_io_range']]],
  ['max_5fvalues_13',['max_values',['../structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046',1,'pw_stream_control']]],
  ['maxsize_14',['maxsize',['../structspa__data.html#ae942ee4f53c1ae2b708fdea5aa334406',1,'spa_data']]],
  ['media_5fclass_15',['media_class',['../structpw__endpoint__info.html#ac9c79172b3c9d4a42d622896d357eb4a',1,'pw_endpoint_info']]],
  ['media_5fsubtype_16',['media_subtype',['../structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0',1,'spa_video_info::media_subtype()'],['../structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75',1,'spa_audio_info::media_subtype()']]],
  ['media_5ftype_17',['media_type',['../structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30',1,'spa_audio_info::media_type()'],['../structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9',1,'spa_video_info::media_type()']]],
  ['mem_18',['mem',['../structpw__buffers.html#af915317f3448e471390a13c48c0d873e',1,'pw_buffers']]],
  ['mem_5fid_19',['mem_id',['../structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392',1,'pw_client_node_buffer']]],
  ['mem_5fsize_20',['mem_size',['../structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6',1,'spa_buffer_alloc_info']]],
  ['message_21',['message',['../structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485',1,'spa_result_node_error']]],
  ['meta_5fsize_22',['meta_size',['../structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617',1,'spa_buffer_alloc_info']]],
  ['metas_23',['metas',['../structspa__buffer__alloc__info.html#aef6e15022383cf49cbba4196111c190d',1,'spa_buffer_alloc_info::metas()'],['../structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e',1,'spa_buffer::metas()']]],
  ['min_24',['min',['../structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c',1,'spa_io_latency::min()'],['../structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62',1,'pw_stream_control::min()']]],
  ['min_5fns_25',['min_ns',['../structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b',1,'spa_latency_info']]],
  ['min_5fquantum_26',['min_quantum',['../structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725',1,'spa_latency_info']]],
  ['min_5frate_27',['min_rate',['../structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101',1,'spa_latency_info']]],
  ['min_5fsize_28',['min_size',['../structspa__io__range.html#af3d7c25e34fd60458e8ca8cfa1067c92',1,'spa_io_range']]],
  ['minutes_29',['minutes',['../structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db',1,'spa_io_segment_video']]],
  ['mjpg_30',['mjpg',['../structspa__video__info.html#a0e442291121d1e295e2db47ead38eb11',1,'spa_video_info']]],
  ['modifier_31',['modifier',['../structspa__video__info__raw.html#acc3883d98af70282cb7536274e0edd74',1,'spa_video_info_raw::modifier()'],['../structspa__video__info__dsp.html#a3b770cfcdcc6cf56ce7f887e7408f374',1,'spa_video_info_dsp::modifier()']]],
  ['multiview_5fflags_32',['multiview_flags',['../structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e',1,'spa_video_info_raw']]],
  ['multiview_5fmode_33',['multiview_mode',['../structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb',1,'spa_video_info_raw']]]
];

==> pipewire-docs-1%3A0.3.70-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/search/variables_d.js <==
var searchData=
[
  ['map_0',['map',['../structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515',1,'pw_memblock']]],
  ['mapoffset_1',['mapoffset',['../structspa__data.html#a75b63dcf6ea09c5908b8682f1696eeae',1,'spa_data']]],
  ['mask_2',['mask',['../structspa__source.html#ad43d6b5fd83f3e86be4f6103009370cd',1,'spa_source']]],
  ['matrix_3',['matrix',['../structspa__video__colorimetry.html#aa2b220b0a2586562f3547505f851fd21',1,'spa_video_colorimetry']]],
  ['max_4',['max',['../structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1',1,'pw_stream_control::max()'],['../structspa__io__latency.html#a5f23744c90a1dc0e9f0c1e067b8d390a',1,'spa_io_latency::max()']]],
  ['max_5falign_5',['max_align',['../structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7',1,'spa_buffer_alloc_info']]],
  ['max_5fframerate_6',['max_framerate',['../structspa__video__info__h264.html#af680ca708a6fac71a3236cb73e1e1fc1',1,'spa_video_info_h264::max_framerate()'],['../structspa__video__info__mjpg.html#a79a7bc729e3b98faa7285d6475b9867b',1,'spa_video_info_mjpg::max_framerate()'],['../structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb',1,'spa_video_info_raw::max_framerate()']]],
  ['max_5finput_5fports_7',['max_input_ports',['../structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e',1,'pw_node_info::max_input_ports()'],['../structspa__node__info.html#a9f05f762157f2ae9db446937f19da173',1,'spa_node_info::max_input_ports()']]],
  ['max_5fns_8',['max_ns',['../structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e',1,'spa_latency_info']]],
  ['max_5foutput_5fports_9',['max_output_ports',['../structpw__node__info.html#ac312e1844784e77e412f6bb341814372',1,'pw_node_info::max_output_ports()'],['../structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5',1,'spa_node_info::max_output_ports()']]],
  ['max_5fquantum_10',['max_quantum',['../structspa__latency__info.html#aab5617769d3799f99a80747917268db8',1,'spa_latency_info']]],
  ['max_5frate_11',['max_rate',['../structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec',1,'spa_latency_info']]],
  ['max_5fsize_12',['max_size',['../structspa__io__range.html#adac0f561e72d269206216a3327720ff7',1,'spa_io_range']]],
  ['max_5fvalues_13',['max_values',['../structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046',1,'pw_stream_control']]],
  ['maxsize_14',['maxsize',['../structspa__data.html#ae942ee4f53c1ae2b708fdea5aa334406',1,'spa_data::maxsize()'],['../structspa__strbuf.html#ac82fdbc33669185a77140a3faf908a0c',1,'spa_strbuf::maxsize()']]],
  ['media_5fclass_15',['media_class',['../structpw__endpoint__info.html#ac9c79172b3c9d4a42d622896d357eb4a',1,'pw_endpoint_info']]],
  ['media_5fsubtype_16',['media_subtype',['../structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0',1,'spa_video_info::media_subtype()'],['../structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75',1,'spa_audio_info::media_subtype()']]],
  ['media_5ftype_17',['media_type',['../structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30',1,'spa_audio_info::media_type()'],['../structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9',1,'spa_video_info::media_type()']]],
  ['mem_18',['mem',['../structpw__buffers.html#af915317f3448e471390a13c48c0d873e',1,'pw_buffers']]],
  ['mem_5fid_19',['mem_id',['../structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392',1,'pw_client_node_buffer']]],
  ['mem_5fsize_20',['mem_size',['../structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6',1,'spa_buffer_alloc_info']]],
  ['message_21',['message',['../structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485',1,'spa_result_node_error']]],
  ['meta_5fsize_22',['meta_size',['../structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617',1,'spa_buffer_alloc_info']]],
  ['metas_23',['metas',['../structspa__buffer__alloc__info.html#aef6e15022383cf49cbba4196111c190d',1,'spa_buffer_alloc_info::metas()'],['../structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e',1,'spa_buffer::metas()']]],
  ['min_24',['min',['../structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c',1,'spa_io_latency::min()'],['../structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62',1,'pw_stream_control::min()']]],
  ['min_5fns_25',['min_ns',['../structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b',1,'spa_latency_info']]],
  ['min_5fquantum_26',['min_quantum',['../structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725',1,'spa_latency_info']]],
  ['min_5frate_27',['min_rate',['../structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101',1,'spa_latency_info']]],
  ['min_5fsize_28',['min_size',['../structspa__io__range.html#af3d7c25e34fd60458e8ca8cfa1067c92',1,'spa_io_range']]],
  ['minutes_29',['minutes',['../structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db',1,'spa_io_segment_video']]],
  ['mjpg_30',['mjpg',['../structspa__video__info.html#a0e442291121d1e295e2db47ead38eb11',1,'spa_video_info']]],
  ['modifier_31',['modifier',['../structspa__video__info__dsp.html#af38a7a5f53d475331ebf38a12994566c',1,'spa_video_info_dsp::modifier()'],['../structspa__video__info__raw.html#a72e94aea5e8202b5a114af286c22a269',1,'spa_video_info_raw::modifier()']]],
  ['mp3_32',['mp3',['../structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b',1,'spa_audio_info']]],
  ['multiview_5fflags_33',['multiview_flags',['../structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e',1,'spa_video_info_raw']]],
  ['multiview_5fmode_34',['multiview_mode',['../structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb',1,'spa_video_info_raw']]]
];
